@@ -92,7 +92,6 @@ default_value = UniqueIdentifier(u'default_value')
 def validator_to_filter(f):
     """Converts the field run_validators method to something suitable for use
     in filter."""
-
     def validate(value):
         try:
             f.run_validators(value)
@@ -123,8 +122,12 @@ def _get_strategy_for_field(f):
                   'ipv4': ip4_addr_strings(), 'ipv6': ip6_addr_strings()}
         strategy = lookup[f.protocol.lower()]
     elif type(f) in (dm.TextField, dm.CharField):
-        strategy = st.text(min_size=(None if f.blank else 1),
-                           max_size=f.max_length)
+        strategy = st.text(
+            alphabet=st.characters(blacklist_characters=u'\x00',
+                                   blacklist_categories=('Cs',)),
+            min_size=(None if f.blank else 1),
+            max_size=f.max_length,
+        )
     elif type(f) == dm.DecimalField:
         bound = Decimal(10 ** f.max_digits - 1) / (10 ** f.decimal_places)
         strategy = st.decimals(min_value=-bound, max_value=bound,
