@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2017 David R. MacIver
+# Most of this work is copyright (C) 2013-2018 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -27,8 +27,8 @@ from hypothesis.searchstrategy.strategies import SearchStrategy, \
 
 
 class OneCharStringStrategy(SearchStrategy):
-
     """A strategy which generates single character strings of text type."""
+
     specifier = text_type
     zero_point = ord('0')
 
@@ -67,7 +67,6 @@ class OneCharStringStrategy(SearchStrategy):
 
 
 class StringStrategy(MappedSearchStrategy):
-
     """A strategy for text strings, defined in terms of a strategy for lists of
     single character text strings."""
 
@@ -77,19 +76,19 @@ class StringStrategy(MappedSearchStrategy):
         )
 
     def __repr__(self):
-        return 'StringStrategy()'
+        return "%r.map(u''.join)" % self.mapped_strategy
 
     def pack(self, ls):
         return u''.join(ls)
 
 
 class BinaryStringStrategy(MappedSearchStrategy):
-
     """A strategy for strings of bytes, defined in terms of a strategy for
     lists of bytes."""
 
     def __repr__(self):
-        return 'BinaryStringStrategy()'
+        return '%r.map(bytearray).map(%s)' % (
+            self.mapped_strategy, binary_type.__name__)
 
     def pack(self, x):
         assert isinstance(x, list), repr(x)
